@@ -27,6 +27,9 @@ import org.w3c.dom.Element;
  */
 public interface Filter extends Condition, Selector {
 
+    /** The type for indirect adjacent selector. */
+    short SAC_INDIRECT_ADJACENT_SELECTOR = 13;
+
     /**
      * Check whether the target element fills this requirement or not.
      * 
