@@ -85,6 +85,11 @@ public class CascadableProperty extends AbstractProperty {
      * @return A specified value.
      */
     private CSSValue getSpecifiedValue(PropertyDefinition definition, int state) {
+        // assert null
+        if (definition == null) {
+            
+        }
+        
         String name = definition.getName();
         CSSValue result;
 
@@ -259,6 +264,15 @@ public class CascadableProperty extends AbstractProperty {
         properties.add(end, set);
     }
 
+    /**
+     * Clear cached style information.
+     */
+    public void clear() {
+        properties.clear();
+        author = 0;
+        user = 0;
+    }
+
     /**
      * DOCUMENT.
      * 
