@@ -96,7 +96,7 @@ public final class DOMUtil {
     public static Element getParentElement(Element target) {
         Node parent = target.getParentNode();
 
-        if (parent.getNodeType() == Node.ELEMENT_NODE) {
+        if (parent != null && parent.getNodeType() == Node.ELEMENT_NODE) {
             return (Element) parent;
         }
         return null;
